#!/bin/sh
# This script must be able to run on busybox-powered devices, so uses POSIX shell instead of bash.

PRODUCT_NAME="metavms"
BASE_DIR="$(dirname "$0")"

getDataDir()
{
    flashCardMountPoint="$(df | grep "/dev/localstorage" | awk '{print $6}')"
    if [ -z "${flashCardMountPoint}" ]; then
        echo "Cannot find the mount point of the SD card." >&2
        exit 1
    fi
    echo -n "${flashCardMountPoint}/${PRODUCT_NAME}.data"
}

getStaticDataDir()
{
    appPath="$1"

    appStorageMountPoint="$( \
        (df "${appPath}" 2>/dev/null || echo "") | tail -1 | awk '{print $6}' )"
    if [ -z "${appStorageMountPoint}" ]; then
        echo "Cannot find the mount point of the internal storage." >&2
        exit 1
    fi
    echo -n "${appStorageMountPoint}/${PRODUCT_NAME}.license"
}

installVms()
{
    appPath="$1"

    dataDir="$(getDataDir)"
    staticDataDir="$(getStaticDataDir "${appPath}")"
    moduleDir="${appPath}/mediaserver"

    userName="$(whoami)"

    # Create data directories and restore config from backup.
    sudo /bin/sh -c "mkdir -p \"${dataDir}\" && chown userName \"${dataDir}\""
    sudo /bin/sh -c "mkdir -p \"${staticDataDir}\" && chown userName \"${staticDataDir}\""
    mkdir -p "${moduleDir}/etc"

    # Update config.
    "${moduleDir}/bin/upgrade_config.sh" \
        "${moduleDir}/etc/mediaserver.conf" \
        "${moduleDir}/share/configs/mediaserver.conf" \
        "${moduleDir}/etc/mediaserver_conf_added_keys.txt" \
        "${moduleDir}/bin/config_helper.sh"

    "${moduleDir}/bin/config_helper.sh" staticDataDir "${staticDataDir}"
    "${moduleDir}/bin/config_helper.sh" dataDir "${dataDir}"
}

removeVms()
{
    appPath="$1"

    moduleDir="${appPath}/mediaserver"

    sudo /bin/sh -c "${moduleDir}/bin/mediaserver.sh stop"

    dataDir="$("${moduleDir}/bin/config_helper.sh" "${moduleDir}/etc/mediaserver.conf" dataDir)"
    if [ -z "${dataDir}" ]; then
        dataDir="$(dirname "${moduleDir}/var")"
    fi
    sudo /bin/sh -c "rm -Rf \"${dataDir}\""
}

main()
{
    cmd="$1"
    appPath="$2"

    exitCode=0
    case "${cmd}" in
        start)
            sudo /bin/sh -c "${appPath}/mediaserver/bin/mediaserver.sh start" >/dev/null 2>&1
            exitCode=$?
            ;;
        stop)
            sudo /bin/sh -c "${appPath}/mediaserver/bin/mediaserver.sh stop"
            exitCode=$?
            ;;
        install)
            echo "Starting Server installation..." > /tmp/nx_install.log
            sudo /bin/sh -c "NX_NO_AUTOSTART=1 ${BASE_DIR}/install.sh" >>/tmp/nx_install.log 2>&1
            ;;
        upgrade)
            echo "Starting Server upgrade..." > /tmp/nx_install.log
            sudo /bin/sh -c "NX_NO_AUTOSTART=1 ${BASE_DIR}/install.sh" >>/tmp/nx_install.log 2>&1
            ;;
        remove)
            removeVms "${appPath}"
            ;;
        *)
            ;;
    esac

    exit ${exitCode}
}

main "$@"
